import Service, { IMessageHandle, IMsgObj, IServiceOption } from './service';
import User from './user';
import Message from './message';
export interface IUserRegistedHandle {
    (userName: string): any;
}
export declare class ServerMessage extends Message {
    /** 如果时通过服务端转发到其他客户端的消息，则有此属性，属性值为服务器实例名 */
    agent: string;
    /** 服务端生成的新消息id */
    smid: string;
    constructor(from: string, to: string, title: string, body: any, reply: string | undefined, group: string | undefined);
}
export default class MessageServer {
    agent: User;
    usersMap: Map<string, User>;
    service: Service;
    timeout: number;
    private _isStarted;
    private _globalUserRegistedHandle;
    private _userRegistedHandlesMap;
    constructor(userName?: string);
    _validateRegist(userName: string): "userName must be string" | "userName can not begin with \"@\"" | "username existed";
    _registAdmin(userName?: string): void;
    start(): this;
    stop(): this;
    restart(): this;
    config(option: IServiceOption): this;
    onMessage(fn: IMessageHandle): this;
    removeMessageHandler(fn: IMessageHandle): this;
    postMessage(msg: IMsgObj, needReplay?: boolean): Promise<unknown>;
    onUserRegisted(fn: IUserRegistedHandle, userName?: string): void;
    broadcast(msg: IMsgObj): void;
}
