/**
 * 云桌面应用间通信协议以及通信消息类
 */
(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    /** 自增长的消息id */
    var msgId = 0;
    const MSG_ID_PREFIX = 'mid_' + Math.floor(Math.random() * 1000) + '_' + Math.floor(Math.random() * 1000) + '_';
    /**
     * Message 类定义
     * @params {string} from 消息发送方的应用实例Id
     * @params {string} to 消息接收方的应用实例Id
     * @params {string} title 消息主题
     * @params {any} body 发送的消息内容, 空消息可发送'',null,undefined
     * @params {number} [reply] 回复消息id，如果是回复某条消息，则有此属性
     */
    class Message {
        constructor(from, to, title, body, reply, group) {
            if (typeof from != 'string' || from == '') {
                throw new Error('from must be string and not empty');
            }
            if (typeof to != 'string' || to == '') {
                throw new Error('to must be string and not empty');
            }
            if (typeof title != 'string' || title == '') {
                throw new Error('title must be string and not empty');
            }
            this.id = MSG_ID_PREFIX + (++msgId);
            this.reply = reply;
            this.from = from;
            this.to = to;
            this.title = title;
            this.body = body;
            this.group = group;
        }
    }
    exports.default = Message;
});
