/**
 * 基于云桌面应用间通信协议实现的基础通信服务
 */
import Message from './message';
export interface IMsgObj {
    /** 回复消息id，如果是回复某条消息，则有此属性 */
    reply?: string;
    /**
     * 消息发送方的标识符，默认为location.href
     */
    from?: string;
    /** 消息接收方的标识符，默认为'_all_' */
    to?: string;
    /** 消息主题 */
    title: string;
    /** 消息内容 */
    body?: any;
    /** 消息组 */
    group?: string;
}
export interface IMessageHandle {
    (event: CrossAppCommunicationEvent): any;
}
export interface IFilter {
    (msg: Message): boolean;
}
export interface IServiceOption {
    filter?: IFilter;
    maxHistory?: number;
}
export declare class CrossAppCommunicationEvent {
    orginEvent: MessageEvent;
    data: Message;
    origin: string;
    source: any;
    msgId: string;
    from: string;
    to: string;
    group: string | undefined;
    constructor(event: MessageEvent);
    /**
     * 快捷回复消息接口
     * @params {MsgObj} msg 消息对象
     * @params {Transferable[]} 转交给消息接收方的特殊对象(ArrayBuffer, MessagePort and ImageBitmap)，发送方将不可时用这些对象了。
     */
    reply(msg: IMsgObj, transfer?: any[]): void;
    destroy(): void;
}
export default class CrossAppCommunicationService {
    private _isStarted;
    private _listeners;
    private _history;
    option: IServiceOption;
    constructor();
    start(): CrossAppCommunicationService;
    stop(): CrossAppCommunicationService;
    restart(): CrossAppCommunicationService;
    config(option: IServiceOption): CrossAppCommunicationService;
    /**
     * 发送消息接口
     * @params {MsgObj|Message} option 消息对象
     * @params {string} option.from 消息发送方的应用实例Id, iframe型应用和desktop可省略
     * @params {string} option.to 消息接收方的应用实例Id, iframe型应用可省略
     * @params {string} option.title 消息主题
     * @params {any} option.body 发送的消息内容, 空消息可发送'',null,undefined
     * @params {number} [option.reply] 回复消息id，如果是回复某条消息，则有此属性
     * @params {string} [targetOrigin] 消息接收方的域，默认为'*', 如果发送的消息中包含密码等信息，最好制定此参数
     * @params {Transferable[]} [transfer] 转交给消息接收方的特殊对象(ArrayBuffer, MessagePort and ImageBitmap)，发送方将不可时用这些对象了。
     * @params {Window} [address] 指定的消息发送地址，window对象
     */
    postMessage(msg: IMsgObj | Message, targetOrigin?: string, transfer?: any[], address?: Window): string;
    /**
     * 监听消息消息接口
     * @params {MessageHandle} fn 消息发送方的应用实例Id, iframe型应用和desktop可省略
     */
    onMessage(fn: IMessageHandle): CrossAppCommunicationService;
    removeMessageHandler(fn: IMessageHandle): void;
    private _logHistory;
    private _onMessageHandle;
}
