/**
 * 云桌面应用间通信协议以及通信消息类
 */

/** 自增长的消息id */
var msgId = 0;
const MSG_ID_PREFIX = 'mid_' + Math.floor(Math.random()*1000) + '_' + Math.floor(Math.random()*1000) + '_';

/**
 * Message 类定义
 * @params {string} from 消息发送方的应用实例Id
 * @params {string} to 消息接收方的应用实例Id
 * @params {string} title 消息主题
 * @params {any} body 发送的消息内容, 空消息可发送'',null,undefined
 * @params {number} [reply] 回复消息id，如果是回复某条消息，则有此属性
 */
export default class Message {
    /** 消息的自增长ID */
    public id: string;
    /** 消息发送方的应用实例Id */
    public from: string;
    /** 消息接收方的应用实例Id */
    public to: string;
    /** 消息主题 */
    public title: string;
    /** 发送的消息内容, 空消息可发送'',null,undefined */
    public body: any;
    /** 回复的消息ID */
    public reply: string|undefined;
    /** 消息组 */
    public group: string|undefined;

    constructor(from: string, to: string, title: string, body: any, reply: string|undefined, group: string|undefined) {
        if (typeof from != 'string' || from == '') {
            throw new Error('from must be string and not empty');
        }
        if (typeof to != 'string' || to == '') {
            throw new Error('to must be string and not empty');
        }
        if (typeof title != 'string' || title == '') {
            throw new Error('title must be string and not empty');
        }

        this.id = MSG_ID_PREFIX + (++msgId);
        this.reply = reply;
        this.from = from;
        this.to = to;
        this.title = title;
        this.body = body;
        this.group = group;
    }
}